@@ -29,7 +29,7 @@ class Mylist(base.BaseObject):
     """
 
     def __str__(self):
-        return "[mylist] %s" %(self.mylistid)
+        return "[mylist] %s" %(self.mid)
 
     def __init__(self, mid=None):
         self.mid = mid
@@ -41,6 +41,8 @@ class Mylist(base.BaseObject):
             ("items",        self._update_via_mylist_list),
             #
             ("favtoken",     self._update_favtoken),
+            #
+            ("mine",        self._update_mine),
         )
 
     def _update_via_rss(self):
@@ -60,7 +62,7 @@ class Mylist(base.BaseObject):
     def _update_via_mylist_list(self):
         url  = "http://www.nicovideo.jp//api/mylist/list?"
         qstr = urllib.urlencode({"token":self.token,"group_id":self.mid})
-        info = json.loads( network.urlopen(url+qstr, "mylistAPI", "mylistgroup/list").read()) 
+        info = json.loads( network.urlopen(url+qstr, "mylistAPI", "mylist/list").read()) 
 
         self._items = []
         class MylistItem(object): pass
@@ -86,6 +88,27 @@ class Mylist(base.BaseObject):
         token_re = r'''FavMylist.csrf_token = "([^"]+)"'''
         self._favtoken = re.search(token_re, html).group(1)
 
+    def _update_mine(self):
+        cmdurl = "http://www.nicovideo.jp//api/mylistgroup/list"
+        q = {}
+        q['token'] = self.token
+        cmdurl += "?" + urllib.urlencode(q)
+        j = json.load( network.urlopen(cmdurl, "mylistAPI", "mylistgroup/list"), encoding='utf8')
+        self._mine = []
+        if j["status"] == 'ok':
+            for item in j["mylistgroup"]:
+                m = Mylist(item["id"])
+                m._name         = item["name"]
+                m._description  = item["description"]
+                m._user_id      = item["user_id"]
+                m._icon_id      = item["icon_id"]
+                m._default_sort = item["default_sort"]
+                m._sort_order   = item["sort_order"]
+                m._public       = item["public"] == u'1'
+                m._update_time  = item["update_time"]
+                m._create_time  = item["create_time"]
+                self._mine.append(m)
+
     def truncate(self):
         """this deletes all items in mylist.
         """
@@ -162,13 +185,3 @@ class Mylist(base.BaseObject):
         req.add_data(data)
         network.urlopen(req,"mylistAPI", "mylist/delete").read()
 
-    def print_summary(self,enc="utf8"):
-        def _pretty(key,value,description):
-            return "%-10s : %-30s" %(key,value)
-        
-        print "[Summary for %s]" % (self.mid)
-        print _pretty("mid",    self.mid,   "mylist_id") 
-        print _pretty("token",  self.token,   "mylist_id") 
-        print _pretty("title",  self.title,   "title") 
-        for i, video in enumerate(self.videolist):
-            print _pretty("item%02d"%(i,), video.title ,"")
