@@ -24,12 +24,12 @@ network_flow_checks = {
     },
     "mylistAPI": { 
         "count":        0,
-        "max_sleep":    1.0,
+        "max_sleep":    1.5,
         "last_invoked": time.time(),
     },
     "searchAPI": { 
         "count":        0,
-        "max_sleep":    1.0,
+        "max_sleep":    1.5,
         "last_invoked": time.time(),
     },
 }
@@ -42,7 +42,7 @@ def urlopen(req, category=None, msg=None):
         interval        = time.time() - network_flow_checks[category]["last_invoked"]
         time_to_sleep   = network_flow_checks[category]["max_sleep"] - interval
         if time_to_sleep > 0:
-            logger.info("NeworkI/O %s reached limit. Sleep %f"%(msg,time_to_sleep))
+            logger.info("NeworkI/O %s reached limit. Sleep %.2f sec."%(msg,time_to_sleep))
             time.sleep(time_to_sleep)
         network_flow_checks[category]["last_invoked"] = time.time()
 
